__auto_eq

Macro __auto_eq 

macro_rules! __auto_eq {
    ($e:expr) => { ... };
}
Macro that wraps the expression with eq(...) if the expression is not a matcher.

This is useful to let users pass expected value to macro matchers like field! and property!. ` For internal use only. API stablility is not guaranteed! If you are interested in using it in your matcher, please file an issue to stabilize this.