succeed

Macro succeed 

macro_rules! succeed {
    ($($message:expr),+ $(,)?) => { ... };
    () => { ... };
}
Generates a success. This does not make the overall test succeed. A test is only considered successful if none of its assertions fail during its execution.

The succeed!() assertion is purely documentary. The only user visible output is a stdout with information on where the success was generated from.

fn test_to_be_implemented() {
    succeed!();
}

One may include formatted arguments in the success message:

fn test_to_be_implemented() {
    succeed!("I am just a fake test: {}", "a fake test indeed");
}