pub fn derefs_to<Inner>(inner: Inner) -> DerefsTo<Inner>Expand description
Dereferences the actual value and verifies that the returned reference
matches the inner matcher.
verify_that!(Box::new(123), derefs_to(eq(&123)))pub fn derefs_to<Inner>(inner: Inner) -> DerefsTo<Inner>Dereferences the actual value and verifies that the returned reference
matches the inner matcher.
verify_that!(Box::new(123), derefs_to(eq(&123)))