pub fn not<InnerMatcherT>(inner: InnerMatcherT) -> NotMatcher<InnerMatcherT>Expand description
Matches the actual value exactly when the inner matcher does not match.
verify_that!(0, not(eq(1)))?; // Passes
verify_that!(0, not(eq(0)))?; // Failspub fn not<InnerMatcherT>(inner: InnerMatcherT) -> NotMatcher<InnerMatcherT>Matches the actual value exactly when the inner matcher does not match.
verify_that!(0, not(eq(1)))?; // Passes
verify_that!(0, not(eq(0)))?; // Fails