pub struct ContainsMatcher<InnerMatcherT> { /* private fields */ }Expand description
A matcher which matches a container containing one or more elements a given
inner Matcher matches.
Implementations
Sourceimpl<InnerMatcherT> ContainsMatcher<InnerMatcherT>
impl<InnerMatcherT> ContainsMatcher<InnerMatcherT>
Sourcepub fn times(self, count: impl Matcher<usize> + 'static) -> Self
pub fn times(self, count: impl Matcher<usize> + 'static) -> Self
Configures this instance to match containers which contain a number of
matching items matched by count.
For example, to assert that exactly three matching items must be present, use:
ⓘ
contains(...).times(eq(3))One can also use times(eq(0)) to test for the absence of an item
matching the expected value.