pub struct PredicateMatcher<P, D1, D2> { /* private fields */ }Expand description
A matcher which applies predicate on the value.
See predicate.
Implementations
Sourceimpl<P> PredicateMatcher<P, NoDescription, NoDescription>
impl<P> PredicateMatcher<P, NoDescription, NoDescription>
Sourcepub fn with_description<D1: PredicateDescription, D2: PredicateDescription>(
self,
positive_description: D1,
negative_description: D2,
) -> PredicateMatcher<P, D1, D2>
pub fn with_description<D1: PredicateDescription, D2: PredicateDescription>( self, positive_description: D1, negative_description: D2, ) -> PredicateMatcher<P, D1, D2>
Configures this instance to provide a more meaningful description.
For example, to make sure the error message is more useful
predicate(|x: i32| x % 2 == 1)
.with_description("is odd", "is even")This is optional as it only provides value when the test fails.
Description can be passed by &str, String or Fn() -> Into<String>.