macro_rules! verify_gt {
($actual:expr, $expected:expr $(,)?) => { ... };
}Expand description
Checks whether the first argument is greater than the second argument.
Evaluates to Result::Ok(()) if the first argument is greater than
the second and Result::Err(TestAssertionFailure) if it is not. The
caller must then decide how to handle the Err variant. It has a few
options:
- Abort the current function with the
?operator. This requires that the function return a suitableResult. - Log the test failure and continue by calling the method
and_log_failure.
Of course, one can also use all other standard methods on Result.
Invoking this macro by itself does not cause a test failure to be recorded
or output. The resulting Result must be handled as described above to
cause the test to be recorded as a failure.
Example:
ⓘ
use googletest::prelude::*;
#[test]
fn should_fail() -> Result<()> {
verify_gt!(1, 2)
}